@@ -3,11 +3,12 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_prereqs_libs check_src_build find_SDL_dir find_file check_header sed_inplace get_dlext);
+our @EXPORT_OK = qw(check_config_script check_prebuilt_binaries check_prereqs_libs check_prereqs_tools check_src_build find_SDL_dir find_file check_header sed_inplace get_dlext);
 use Config;
 use ExtUtils::CBuilder;
 use File::Spec::Functions qw(splitdir catdir splitpath catpath rel2abs);
 use File::Find qw(find);
+use File::Which;
 use File::Copy qw(cp);
 use Cwd qw(realpath);
 
@@ -75,6 +76,9 @@ my $source_packs = [
           'http://froggs.de/libz/zlib-1.2.5.tar.gz',
         ],
         sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
+        patches => [
+          'zlib-1.2.5-bsd-ldconfig.patch',
+        ],
       },
       {
         pack => 'SDL',
@@ -310,6 +314,9 @@ my $source_packs = [
           'http://froggs.de/libz/zlib-1.2.5.tar.gz',
         ],
         sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
+        patches => [
+          'zlib-1.2.5-bsd-ldconfig.patch',
+        ],
       },
       {
         pack => 'jpeg',
@@ -422,6 +429,9 @@ my $source_packs = [
           'http://froggs.de/libz/zlib-1.2.5.tar.gz',
         ],
         sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
+        patches => [
+          'zlib-1.2.5-bsd-ldconfig.patch',
+        ],
       },
       {
         pack => 'jpeg',
@@ -512,6 +522,9 @@ my $source_packs = [
           'http://froggs.de/libz/zlib-1.2.5.tar.gz',
         ],
         sha1sum  => '8e8b93fa5eb80df1afe5422309dca42964562d7e',
+        patches => [
+          'zlib-1.2.5-bsd-ldconfig.patch',
+        ],
       },
       {
         pack => 'jpeg',
@@ -728,13 +741,32 @@ sub check_prereqs {
   return $ret;
 }
 
+sub check_prereqs_tools {
+  my @tools = @_;
+  my $ret  = 1;
+
+  foreach my $tool (@tools) {
+    
+    if(-x File::Which::which($tool)
+    || ('pkg-config' eq $tool && defined $ENV{PKG_CONFIG} && $ENV{PKG_CONFIG} && -x File::Which::which($ENV{PKG_CONFIG}))) {
+      $ret &= 1;
+    }
+    else {
+      print "WARNING: required '$tool' not found\n";
+      $ret = 0;
+    }
+  }
+
+  return $ret;
+}
+
 sub find_file {
   my ($dir, $re) = @_;
   my @files;
   $re ||= qr/.*/;
   {
     #hide warning "Can't opendir(...): Permission denied - fix for http://rt.cpan.org/Public/Bug/Display.html?id=57232
-    no warnings 'File::Find';
+    no warnings;
     find({ wanted => sub { push @files, rel2abs($_) if /$re/ }, follow => 1, no_chdir => 1 , follow_skip => 2}, $dir);
   };
   return @files;
